@@ -26,7 +26,7 @@ class App(object):
         self.update_time = update_time
         self.update_user_id = update_user_id
 
-    def update(self, name, tags, desc):
+    def update(self, name=None, tags=None, desc=None):
         """
         更新模型基础信息
         :param tags:应用标签
@@ -34,21 +34,21 @@ class App(object):
         :param desc:应用备注
         :return: Class `app` Object
         """
-        return self._backend.update_app(self.id, name, tags, desc)
+        return self._backend.update_app(name, tags, desc)
 
     def delete(self):
         """
         删除当前应用
         :return:
         """
-        return self._backend.delete_app(self.id)
+        return self._backend.delete_app()
 
     def list_models(self):
         """
         获取应用下模型对象列表
         :return: List of Class `Model` Object
         """
-        return self._backend.list_models(self.id)
+        return self._backend.list_models()
 
     def create_model(self, name, desc='', auth_id='', git_url='', http_url=''):
         """
@@ -60,4 +60,4 @@ class App(object):
         :param desc:模型备注
         :return: List of Class `Model` Object
         """
-        return self._backend.create_model(self.id, name, desc, auth_id, git_url, http_url)
+        return self._backend.create_model(name, desc, auth_id, git_url, http_url)
