@@ -10,6 +10,7 @@
 """
 
 import logging
+from waveletai.constants import DataSource, FileExt
 
 _logger = logging.getLogger(__name__)
 
@@ -99,6 +100,27 @@ class Dataset(object):
         """upload data_asset files"""
         return self._backend.upload_dataset_artifacts(self.id, path)
 
+    def download_data(self, path="raw_data.csv", destination_dir=None, datasource=DataSource.MAMMUT.value,
+                      fileext=FileExt.CSV.value, query=None):
+        """
+        当dataset仅为外部数据引用时，下载对应源的rawdata
+        :param path to the file to be downloaded. path=raw_data.csv
+        :param destination_dir (:obj:`str`): default current dir
+        :param datasource (:obj:`str`): Constants.DataSource 数据来源,默认MAMMUT
+        :param fileext (:obj:`str`): Constants.FileExt 文件保存格式，默认csv
+        :param query (:obj:`dict`): 自定义参数,当为{}时，将使用数据的默认参数请求数据
+        Examples:
+             .. code:: python3
+
+                dataset.download_data()
+
+                dataset.download_data(path='raw_data.csv',destination_dir='dataset/'
+                   query={"page_num":1,"startTime":"2021-08-25","endTime":"2021-08-26","page_size":3000})
+        """
+        if query is None:
+            query = {}
+        return self._backend.download_data(self.id, path, destination_dir, datasource, fileext, query)
+
 
 class Asset(object):
     def __init__(self, id, name, path, content_type, size, asset_type, dataset_id):
